@@ -3,19 +3,18 @@ import sys
 import netifaces
 
 import inject
-from mfcloud.plugins.datadog import DatadogPlugin
-from mfcloud.plugins.hosts import HostsPlugin
-from mfcloud.plugins.internal_api import InternalApiPlugin
-from mfcloud.plugins.metrics import MetricsPlugin
-
-from mfcloud.util import txtimeout
-import os
+from mfcloud.application import ApplicationVolumeResolver
 from twisted.internet import reactor
 from twisted.internet.defer import inlineCallbacks
-from twisted.internet.protocol import Factory, AbstractDatagramProtocol
+from twisted.internet.protocol import Factory
 import txredisapi
-
 from twisted.python import log
+
+from mfcloud.plugins.internal_api import InternalApiPlugin
+from mfcloud.plugins.metrics import MetricsPlugin
+from mfcloud.sendfile import FileIOFactory, FileServer
+from mfcloud.util import txtimeout
+
 log.startLogging(sys.stdout)
 
 Factory.noisy = False
@@ -26,6 +25,7 @@ def get_argparser():
 
     parser = argparse.ArgumentParser(description='Mfcloud rpc server')
     parser.add_argument('--port', type=int, default=7080, help='port number')
+    parser.add_argument('--file-port', type=int, default=7081, help='File transfer port number')
     parser.add_argument('--haproxy', default=False, action='store_true', help='Update haproxy config')
     # parser.add_argument('--dns', type=bool, default=True, action='store_true', help='Start dns server')
     # parser.add_argument('--events', type=bool, default=True, action='store_true', help='Start dns server')
@@ -54,6 +54,7 @@ def entry_point():
 
     rpc_interface = args.interface
     rpc_port = args.port
+    file_port = args.file_port
 
     if not args.dns_server_ip:
         dns_server_ip = netifaces.ifaddresses('docker0')[netifaces.AF_INET][0]['addr']
@@ -63,7 +64,6 @@ def entry_point():
     dns_prefix = args.dns_search_suffix
 
     from confire import Configuration
-    from confire import environ_setting
 
     class SslConfiguration(Configuration):
         enabled = False
@@ -87,7 +87,7 @@ def entry_point():
     @inlineCallbacks
     def run_server(redis):
 
-        from mfcloud.dns_resolver import listen_dns, dump_resolv_conf
+        from mfcloud.dns_resolver import listen_dns
         from mfcloud.events import EventBus
         from mfcloud.plugins.dns import DnsPlugin
         from mfcloud.plugins.haproxy import HaproxyPlugin
@@ -123,11 +123,14 @@ def entry_point():
         tasks = inject.instance(TaskService)
         api.tasks = tasks.collect_tasks()
 
-
-        log.msg('Starting rpc listener')
+        log.msg('Starting rpc listener on port %d' % rpc_port)
         server = Server(port=rpc_port)
         server.bind()
 
+        log.msg('Starting file listener on port %d' % file_port)
+        file_server = FileServer(host='localhost', port=file_port, file_resolver=ApplicationVolumeResolver())
+        file_server.bind()
+
         log.msg('Dumping resolv conf')
 
         # dns
